@@ -48,6 +48,7 @@
 #include "location-distance-utils-fix.h"
 
 /* Other modules */
+#include "upload_dlg.h"
 #include "gconf_keys.h"
 #include "gpx_parser.h"
 #include "ec-button.h"
@@ -550,6 +551,8 @@ static void analyzer_view_draw_heart_rate(
 
 static void analyzer_view_set_units(AnalyzerView *self);
 static void create_map(gpointer user_data);
+static void upload_button_clicked (GtkButton *button, gpointer user_data);
+
 
 /**
  * @brief Free memory used by a #AnalyzerViewTrack
@@ -616,11 +619,10 @@ void analyzer_view_set_default_folder(
 
 	DEBUG_END();
 }
-
+/*legacy code */
 static GtkWidget *create_table ()
 {
 
-  GtkWidget *hbox;
   GtkWidget *table;
   GtkWidget *button;
   char buffer[32];
@@ -654,16 +656,27 @@ void analyzer_view_show(AnalyzerView *self)
 {
 	gint i;
 	PangoFontDescription *desc;
-
+	
 	g_return_if_fail(self != NULL);
 	DEBUG_BEGIN();
 
 	self->win = hildon_stackable_window_new ();
 	gtk_window_set_title ( GTK_WINDOW (self->win), "eCoach >Activity log");
 	gtk_widget_set_name(GTK_WIDGET(self->win), "mainwindow");
+	self->menu = hildon_app_menu_new ();
+	self->menu_button = hildon_gtk_button_new (HILDON_SIZE_AUTO);
+	gtk_widget_set_sensitive(self->menu_button,FALSE);
+	gtk_button_set_label (GTK_BUTTON (self->menu_button),"Upload to HeiaHeia");
 
+        g_signal_connect_after (self->menu_button, "clicked",
+                            G_CALLBACK (upload_button_clicked),
+                            self);
+ 	hildon_app_menu_append (HILDON_APP_MENU(self->menu), GTK_BUTTON (self->menu_button));
+	hildon_window_set_app_menu (HILDON_WINDOW (self->win),HILDON_APP_MENU(self->menu));
+
+	gtk_widget_show_all(self->menu);
 	g_signal_connect (self->win, "destroy", G_CALLBACK (analyzer_view_hide), self);
-
+	
 
 	self->main_table = gtk_table_new(5,2,TRUE);
 	
@@ -794,7 +807,7 @@ void analyzer_view_show(AnalyzerView *self)
 
 	self->pannable = hildon_pannable_area_new ();
 	gtk_widget_set_name(GTK_WIDGET(self->pannable), "mainwindow");
-	g_object_set (G_OBJECT(self->pannable),"mov-mode", HILDON_MOVEMENT_MODE_HORIZ );
+	g_object_set (G_OBJECT(self->pannable),"mov-mode", HILDON_MOVEMENT_MODE_HORIZ,NULL);
 
 	//g_object_set (G_OBJECT (self->pannable),"low-friction-mode", TRUE);
 
@@ -1405,7 +1418,7 @@ static void analyzer_view_btn_open_clicked(
 				self,
 				(AnalyzerViewTrack *)self->tracks->data);
 	}
-
+	
 	g_free(file_name);
 	DEBUG_END();
 }
@@ -1517,7 +1530,7 @@ gboolean
 map_button_release_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
 {
 
-     AnalyzerView *self = (AnalyzerView *)user_data;
+  //   AnalyzerView *self = (AnalyzerView *)user_data;
      if(user_data == NULL){ return FALSE;}
       DEBUG_BEGIN();
     float lat,lon;
@@ -1568,7 +1581,7 @@ static void analyzer_view_btn_map_clicked(
 		GtkWidget *button,
 		gpointer user_data)
 {
-  AnalyzerViewTrack *track = NULL;
+ // AnalyzerViewTrack *track = NULL;
   AnalyzerView *self = (AnalyzerView *)user_data;
 
   DEBUG_BEGIN();
@@ -1627,7 +1640,7 @@ static gchar *analyzer_view_choose_file_name(AnalyzerView *self)
 			GTK_FILE_CHOOSER(file_dialog),
 			self->default_folder_name);
 
-	gtk_widget_show_all(file_dialog);
+	gtk_widget_show_all(file_dialog);	
 	result = gtk_dialog_run(GTK_DIALOG(file_dialog));
 
 	if(result == GTK_RESPONSE_CANCEL)
@@ -1693,7 +1706,7 @@ static void analyzer_view_clear_data(AnalyzerView *self)
 	self->tracks = NULL;
 
 	self->current_track_number = 0;
-
+	gtk_widget_set_sensitive(self->menu_button,FALSE);
 	gtk_widget_queue_draw(self->graphs_drawing_area);
 
 	DEBUG_END();
@@ -1755,7 +1768,10 @@ static void analyzer_view_add_track(
 	self->tracks = g_slist_prepend(self->tracks, track);
 
 	track->name = g_strdup(parser_track->name);
-//	track->comment = g_strdup(parser_track->comment);
+	if(parser_track->comment  != NULL){
+	track->comment = g_strdup(parser_track->comment);
+        self->comment = track->comment;
+	}
 	track->number = parser_track->number;
 
 	/* All other data is initialized correctly with g_new0 */
@@ -2586,8 +2602,16 @@ static void analyzer_view_show_track_information(
 	{
 		gtk_widget_queue_draw(self->graphs_drawing_area);
 	}
-
-	DEBUG_END();
+	gtk_widget_set_sensitive(self->menu_button, TRUE);
+	 self->heart_rate_avg = track->heart_rate_avg;
+	 self->heart_rate_max = track->heart_rate_max;
+	 self->duration = track->duration;
+         self->distance = track->distance;
+	 self->start_time = track->start_time;
+	
+	 self->name = track->name;
+	 
+	 DEBUG_END();
 }
 
 static void analyzer_view_graphs_btn_speed_clicked(
@@ -3792,3 +3816,9 @@ static void analyzer_view_set_units(AnalyzerView *self)
 	gtk_widget_destroy (dialog);
 
 }
+static void upload_button_clicked (GtkButton *button, gpointer user_data){
+
+AnalyzerView *self = (AnalyzerView *)user_data;
+upload(self);
+
+}
