@@ -36,6 +36,9 @@
 #include "gpx_parser.h"
 #include "gconf_helper.h"
 
+/* Osso */
+#include <libosso.h>
+
 /*****************************************************************************
  * Enumerations                                                              *
  *****************************************************************************/
@@ -77,9 +80,23 @@ typedef struct _AnalyzerView {
 	GtkWidget *map_win;
 	gchar *default_folder_name;
 
+	
+		/*for heiaheia */
+	gdouble distance;
+	gint heart_rate_avg;
+	gint heart_rate_max;
+	struct timeval duration;
+	struct timeval start_time;
+	gchar* comment;
+	gchar* name;
+	GtkWidget *dialog;
+	GtkWidget * menu_button;
+	int status;
+
+	
+	
 	/* Following members are created when the view is shown and destroyed
 	 * when the view is hidden */
-
 	GtkWidget *win;
 	GtkWidget *vbox;
 	GtkWidget *main_table;
@@ -90,6 +107,7 @@ typedef struct _AnalyzerView {
 	GtkWidget *lbl_track_number;
 	GtkWidget *lbl_track_details;
 
+	GtkWidget *menu;
 	GtkWidget *scrolled;
 	GtkWidget *pannable;
 	/* Container for the different views */
@@ -105,7 +123,7 @@ typedef struct _AnalyzerView {
 
 	GtkWidget *pan;
 	GtkWidget *data;
-	
+
 	/* Data for info view */
 	GtkWidget *info_table;
 
@@ -142,6 +160,7 @@ typedef struct _AnalyzerView {
 	gdouble lat,lon;
 	GdkPixbuf *zoom_in;
 	GdkPixbuf *zoom_out;
+	osso_context_t *osso;
 	/* Data that is parsed from tracks */
 
 	/**
